@@ -10,7 +10,7 @@ from .Component import Component
 from .SendToLogzIo import SendTOLogzIo
 from .debug_mode import DebugMode
 from user_context_remote.user_context import UserContext
-
+from .LoggerOutputEnum import LoggerOutputEnum
 
 
 logzio_token = os.getenv("LOGZIO_TOKEN")
@@ -22,8 +22,7 @@ loggers={}
 class Logger:
     @staticmethod
     def create_logger(**kwargs):
-        if(os.getenv("ENVIRONMENT_NAME") is None):
-            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called ENVIRONMENT_NAME=local or play1 (instead of ENVIRONMENT)")
+        Logger._validate_enviroment_variables()
         if('component_id' not in kwargs['object'] or "component_name" not in kwargs['object'] or "component_category" not in kwargs['object'] or "developer_email" not in kwargs['object']):
             raise Exception("please insert component_id, component_name, component_category and developer_email in your object")
         component_id=kwargs['object']['component_id']
@@ -33,30 +32,34 @@ class Logger:
             logger=Logger(**kwargs)
             loggers[component_id]=logger
             return logger
+    
     def __init__(self,**kwargs):
         if (logzio_token is None):
             raise Exception(
                 "Please set in your .env file LOGZIO_TOKEN=cXNHuVkkffkilnkKzZlWExECRlSKqopE")
+        self.component_id=kwargs['object']['component_id']
         self.fields = {}
         self._writer = Writer()
         self.logzio_handler = SendTOLogzIo()
         self.writeToSql = False
         self.additinal_fields = {}
-        self.user=UserContext.login()
         self.init(**kwargs)
         DebugMode.init()
 
 
     def init(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Init.value):
+            print(f'LoggerService.init(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             self.insertVariables(**kwargs)
             kwargs['object']['severity_id'] = MessageSeverity.Init.value
             kwargs['object']['severity_name'] = MessageSeverity.Init.name
             kwargs['object']['log_message'] = log_message
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Init.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Init.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -67,29 +70,34 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Init.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Init.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     self.insertVariables(**kwargs)
                     kwargs['object']['severity_id'] = MessageSeverity.Init.value
                     kwargs['object']['severity_name'] = MessageSeverity.Init.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
-                    if (self.writeToSql == True):
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Init.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Init.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def start(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Start.value):
+            print(f'LoggerService.start(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Start.value
             kwargs['object']['severity_name'] = MessageSeverity.Start.name
             kwargs['object']['log_message'] = log_message
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
             self.insert_To_object(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Start.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Start.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -100,29 +108,34 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Start.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Start.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.Start.value
                     kwargs['object']['severity_name'] = MessageSeverity.Start.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Start.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Start.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def end(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.End.value):
+            print(f'LoggerService.end(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.End.value
             kwargs['object']['severity_name'] = MessageSeverity.End.name
             kwargs['object']['log_message'] = log_message
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
             self.insert_To_object(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.End.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.End.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -133,20 +146,24 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.End.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.End.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.End.value
                     kwargs['object']['severity_name'] = MessageSeverity.End.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.End.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.End.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def exception(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Exception.value):
+            print(f'LoggerService.exception(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             stack_trace = traceback.format_exception(
                 type(kwargs['object']), kwargs['object'], kwargs['object'].__traceback__)
@@ -158,9 +175,10 @@ class Logger:
             }
             object_exp = self.insert_to_payload_extra_vars(object=object_exp)
             self.insert_To_object(**object_exp)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Exception.value):
                 self._writer.addMessageAndPayload(log_message, **object_exp)
-            self.logzio_handler.send_to_logzio(object_exp['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Exception.value):
+                self.logzio_handler.send_to_logzio(object_exp['object'])
         else:
             if log_message:
                 log_object = {
@@ -171,9 +189,10 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Exception.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Exception.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     stack_trace = traceback.format_exception(
@@ -186,20 +205,24 @@ class Logger:
                     object_exp = self.insert_to_payload_extra_vars(
                         object=object_exp)
                     self.insert_To_object(**object_exp)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Exception.value):
                         self._writer.add(**object_exp)
-                    self.logzio_handler.send_to_logzio(object_exp['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Exception.value):
+                        self.logzio_handler.send_to_logzio(object_exp['object'])
 
     def info(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Information.value):
+            print(f'LoggerService.info(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Information.value
             kwargs['object']['severity_name'] = MessageSeverity.Information.name
             kwargs['object']['log_message'] = log_message
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
             self.insert_To_object(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Information.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Information.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -210,61 +233,71 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Information.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Information.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.Information.value
                     kwargs['object']['severity_name'] = MessageSeverity.Information.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Information.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Information.value):
+                         self.logzio_handler.send_to_logzio(kwargs['object'])
 
-    def error(self, message=None, **kwargs):
-        if message and 'object' in kwargs:
+    def error(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Error.value):
+            print(f'LoggerService.error(log_message= {log_message} kwargs= {kwargs})')
+        if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Error.value
             kwargs['object']['severity_name'] = MessageSeverity.Error.name
-            kwargs['object']['log_message'] = message
+            kwargs['object']['log_message'] = log_message
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
             self.insert_To_object(**kwargs)
-            if self.writeToSql == True:
-                self._writer.addMessageAndPayload(message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Error.value):
+                self._writer.addMessageAndPayload(log_message, **kwargs)
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Error.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
-            if message:
+            if log_message:
                 log_object = {
                     'severity_id': MessageSeverity.Error.value,
                     'severity_name': MessageSeverity.Error.name,
                 }
-                log_object['log_message'] = message
+                log_object['log_message'] = log_message
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
-                    self._writer.addMessageAndPayload(message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Error.value):
+                    self._writer.addMessageAndPayload(log_message, **kwargs)
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Error.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.Error.value
                     kwargs['object']['severity_name'] = MessageSeverity.Error.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Error.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Error.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def warn(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Warning.value):
+            print(f'LoggerService.warn(args= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Warning.value
             kwargs['object']['severity_name'] = MessageSeverity.Warning.name
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
             self.insert_To_object(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Warning.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Warning.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -275,29 +308,34 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Warning.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Warning.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity. Warning.value
                     kwargs['object']['severity_name'] = MessageSeverity.Warning.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Warning.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Warning.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def debug(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Debug.value):
+            print(f'LoggerService.debug(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Debug.value
             kwargs['object']['severity_name'] = MessageSeverity.Debug.name
             kwargs['object']['log_message'] = log_message
             self.insert_To_object(**kwargs)
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Debug.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Debug.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -308,29 +346,34 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Debug.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Debug.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.Debug.value
                     kwargs['object']['severity_name'] = MessageSeverity.Debug.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Debug.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Debug.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def critical(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Critical.value):
+            print(f'LoggerService.critical(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Critical.value
             kwargs['object']['severity_name'] = MessageSeverity.Critical.name
             kwargs['object']['log_message'] = log_message
             self.insert_To_object(**kwargs)
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Critical.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Critical.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -341,29 +384,34 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Critical.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Critical.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.Critical.value
                     kwargs['object']['severity_name'] = MessageSeverity.Critical.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Critical.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Critical.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def verbose(self, log_message=None, **kwargs):
+        if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Console,MessageSeverity.Verbose.value):
+            print(f'LoggerService.verbose(log_message= {log_message} kwargs= {kwargs})')
         if log_message and 'object' in kwargs:
             kwargs['object']['severity_id'] = MessageSeverity.Verbose.value
             kwargs['object']['severity_name'] = MessageSeverity.Verbose.name
             kwargs['object']['log_message'] = log_message
             kwargs = self.insert_to_payload_extra_vars(**kwargs)
             self.insert_To_object(**kwargs)
-            if self.writeToSql == True:
+            if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Verbose.value):
                 self._writer.addMessageAndPayload(log_message, **kwargs)
-            self.logzio_handler.send_to_logzio(kwargs['object'])
+            if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Verbose.value):
+                self.logzio_handler.send_to_logzio(kwargs['object'])
         else:
             if log_message:
                 log_object = {
@@ -374,18 +422,20 @@ class Logger:
                 kwargs['object'] = log_object
                 kwargs = self.insert_to_payload_extra_vars(**kwargs)
                 self.insert_To_object(**kwargs)
-                if self.writeToSql:
+                if self.writeToSql and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Verbose.value):
                     self._writer.addMessageAndPayload(log_message, **kwargs)
-                self.logzio_handler.send_to_logzio(kwargs['object'])
+                if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Verbose.value):
+                    self.logzio_handler.send_to_logzio(kwargs['object'])
             else:
                 if 'object' in kwargs:
                     kwargs['object']['severity_id'] = MessageSeverity.Verbose.value
                     kwargs['object']['severity_name'] = MessageSeverity.Verbose.name
                     kwargs = self.insert_to_payload_extra_vars(**kwargs)
                     self.insert_To_object(**kwargs)
-                    if self.writeToSql == True:
+                    if self.writeToSql == True and DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.MySQLDatabase,MessageSeverity.Verbose.value):
                         self._writer.add(**kwargs)
-                    self.logzio_handler.send_to_logzio(kwargs['object'])
+                    if DebugMode.is_logger_output(self.component_id,LoggerOutputEnum.Logzio,MessageSeverity.Verbose.value):
+                        self.logzio_handler.send_to_logzio(kwargs['object'])
 
     def insertVariables(self, **object):
         object_data = object.get("object", {})
@@ -417,13 +467,19 @@ class Logger:
         self.additinal_fields.clear()
 
     def insert_to_payload_extra_vars(self, **kwargs):
-        kwargs['object']['user_id'] = self.user.get_real_user_id()
-        kwargs['object']['created_user_id'] = self.user.get_real_user_id()
-        kwargs['object']['profile_id'] = self.user.get_real_profile_id()
-        if self.user.name is not None:
-            kwargs['object']['current_runner'] = self.user.get_real_name()
-        else:
-            kwargs['object']['current_runner'] = os.getenv("PRODUCT_USERNAME")
+        self.userContext=UserContext.login_using_user_identification_and_password(os.getenv("PRODUCT_USER_IDENTIFIER"),os.getenv("PRODUCT_PASSWORD"))
+        if self.userContext is not None:
+            # TODO Shall we change in the database column to real_user_id?
+            kwargs['object']['user_id'] = self.userContext.get_real_user_id()
+            kwargs['object']['created_user_id'] = self.userContext.get_real_user_id()
+            # TODO Shall we change the database to store real_profile_id and effective_profile?
+            kwargs['object']['profile_id'] = self.userContext.get_real_profile_id()
+            # TODO: change to display_as like we have in contact ...
+            if self.userContext.real_display_name is not None:
+                # TODO Shall we change current_runner to real_name?
+                kwargs['object']['current_runner'] = self.userContext.get_real_name()
+            else:
+                kwargs['object']['current_runner'] = os.getenv("PRODUCT_USER_IDENTIFIER")
         message = kwargs['object'].pop('message', None)
         kwargs['object']['function'] = self.get_current_function_name()
         kwargs['object']['environment'] = os.getenv("ENVIRONMENT_NAME")
@@ -519,5 +575,16 @@ class Logger:
                   sql_query+" Exception=" + str(e), file=sys.stderr)
             return None
     
+    @staticmethod
+    def _validate_enviroment_variables():
+        if(os.getenv("ENVIRONMENT_NAME") is None):
+            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called ENVIRONMENT_NAME=local or play1 (instead of ENVIRONMENT)")
+        if(os.getenv("PRODUCT_USER_IDENTIFIER") is None):
+            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called PRODUCT_USER_IDENTIFIER (instead of PRODUCT_USERNAME)")
+        if(os.getenv("PRODUCT_PASSWORD") is None):
+            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called PRODUCT_PASSWORD")
+        if(os.getenv("LOGZIO_TOKEN") is None):
+            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called LOGZIO_TOKEN=cXNHuVkkffkilnkKzZlWExECRlSKqopE")
+    
 
 
